@@ -25,7 +25,7 @@
 
 G_BEGIN_DECLS
 
-#include <gsystem-local-alloc.h>
+#include <gsystem-console.h>
 #include <gsystem-file-utils.h>
 #include <gsystem-shutil.h>
 #include <gsystem-subprocess.h>
