@@ -87,47 +87,20 @@ typedef enum {
  */
 #define OSTREE_COMMIT_GVARIANT_FORMAT G_VARIANT_TYPE ("(a{sv}aya(say)sstayay)")
 
-/* Pack super index
- * s - OSTv0SUPERPACKINDEX
- * a{sv} - Metadata
- * a(ayay) - metadata packs (pack file checksum, bloom filter)
- * a(ayay) - data packs (pack file checksum, bloom filter)
+/*
+ * filez objects:
+ * <BE guint32 containing variant length>
+ * t - size
+ * u - uid
+ * u - gid
+ * u - mode
+ * u - rdev
+ * s - symlink target 
+ * a(ayay) - xattrs
+ * ---
+ * zlib-compressed data
  */
-#define OSTREE_PACK_SUPER_INDEX_VARIANT_FORMAT G_VARIANT_TYPE ("(sa{sv}a(ayay)a(ayay))")
-
-/* Pack index
- * s - OSTv0PACKINDEX
- * a{sv} - Metadata
- * a(yayt) - (objtype, checksum, offset into packfile)
- */
-#define OSTREE_PACK_INDEX_VARIANT_FORMAT G_VARIANT_TYPE ("(sa{sv}a(yayt))")
-
-typedef enum {
-  OSTREE_PACK_FILE_ENTRY_FLAG_NONE = 0,
-  OSTREE_PACK_FILE_ENTRY_FLAG_GZIP = (1 << 0)
-} OstreePackFileEntryFlag;
-
-/* Data Pack files
- * s - OSTv0PACKDATAFILE
- * a{sv} - Metadata
- * t - number of entries
- *
- * Repeating pair of:
- * <padding to alignment of 8>
- * ( ayy(uuuusa(ayay))ay) ) - checksum, flags, file meta, data
- */
-#define OSTREE_PACK_DATA_FILE_VARIANT_FORMAT G_VARIANT_TYPE ("(ayy(uuuusa(ayay))ay)")
-
-/* Meta Pack files
- * s - OSTv0PACKMETAFILE
- * a{sv} - Metadata
- * t - number of entries
- *
- * Repeating pair of:
- * <padding to alignment of 8>
- * ( yayv ) - objtype, checksum, data
- */
-#define OSTREE_PACK_META_FILE_VARIANT_FORMAT G_VARIANT_TYPE ("(yayv)")
+#define OSTREE_ZLIB_FILE_HEADER_GVARIANT_FORMAT G_VARIANT_TYPE ("(tuuuusa(ayay))")
 
 const GVariantType *ostree_metadata_variant_type (OstreeObjectType objtype);
 
@@ -140,6 +113,9 @@ GVariant *ostree_checksum_to_bytes_v (const char *checksum);
 char * ostree_checksum_from_bytes (const guchar *bytes);
 char * ostree_checksum_from_bytes_v (GVariant *bytes);
 
+void ostree_checksum_inplace_from_bytes (const guchar *bytes,
+                                         char         *buf);
+
 const guchar *ostree_checksum_bytes_peek (GVariant *bytes);
 
 int ostree_cmp_checksum_bytes (const guchar *a, const guchar *b);
@@ -169,20 +145,11 @@ void ostree_object_from_string (const char *str,
                                 OstreeObjectType *out_objtype);
 
 char *ostree_get_relative_object_path (const char        *checksum,
-                                       OstreeObjectType   type);
+                                       OstreeObjectType   type,
+                                       gboolean           compressed);
 
 char *ostree_get_relative_archive_content_path (const char        *checksum);
 
-char *ostree_get_pack_index_name (gboolean        is_meta,
-                                  const char     *checksum);
-char *ostree_get_pack_data_name (gboolean        is_meta,
-                                 const char     *checksum);
-
-char *ostree_get_relative_pack_index_path (gboolean        is_meta,
-                                           const char     *checksum);
-char *ostree_get_relative_pack_data_path (gboolean        is_meta,
-                                          const char     *checksum);
-
 gboolean ostree_get_xattrs_for_file (GFile         *f,
                                      GVariant     **out_xattrs,
                                      GCancellable  *cancellable,
@@ -196,9 +163,6 @@ gboolean ostree_map_metadata_file (GFile                       *file,
                                    GVariant                   **out_variant,
                                    GError                     **error);
 
-GVariant *ostree_file_header_new (GFileInfo         *file_info,
-                                  GVariant          *xattrs);
-
 gboolean ostree_write_variant_with_size (GOutputStream      *output,
                                          GVariant           *variant,
                                          guint64             alignment_offset,
@@ -207,12 +171,23 @@ gboolean ostree_write_variant_with_size (GOutputStream      *output,
                                          GCancellable       *cancellable,
                                          GError            **error);
 
+GVariant *ostree_file_header_new (GFileInfo         *file_info,
+                                  GVariant          *xattrs);
+GVariant *ostree_zlib_file_header_new (GFileInfo         *file_info,
+                                       GVariant          *xattrs);
+
 gboolean ostree_file_header_parse (GVariant         *data,
                                    GFileInfo       **out_file_info,
                                    GVariant        **out_xattrs,
                                    GError          **error);
+gboolean ostree_zlib_file_header_parse (GVariant         *data,
+                                        GFileInfo       **out_file_info,
+                                        GVariant        **out_xattrs,
+                                        GError          **error);
+
 gboolean
-ostree_content_stream_parse (GInputStream           *input,
+ostree_content_stream_parse (gboolean                compressed,
+                             GInputStream           *input,
                              guint64                 input_length,
                              gboolean                trusted,
                              GInputStream          **out_input,
@@ -221,7 +196,8 @@ ostree_content_stream_parse (GInputStream           *input,
                              GCancellable           *cancellable,
                              GError                **error);
 
-gboolean ostree_content_file_parse (GFile                  *content_path,
+gboolean ostree_content_file_parse (gboolean                compressed,
+                                    GFile                  *content_path,
                                     gboolean                trusted,
                                     GInputStream          **out_input,
                                     GFileInfo             **out_file_info,
@@ -297,34 +273,12 @@ gboolean ostree_create_temp_regular_file (GFile            *dir,
                                           GCancellable     *cancellable,
                                           GError          **error);
 
-gboolean ostree_create_temp_hardlink (GFile            *dir,
-                                      GFile            *src,
-                                      const char       *prefix,
-                                      const char       *suffix,
-                                      GFile           **out_file,
-                                      GCancellable     *cancellable,
-                                      GError          **error);
-
-gboolean ostree_read_pack_entry_raw (guchar           *pack_data,
-                                     guint64           pack_len,
-                                     guint64           object_offset,
-                                     gboolean          trusted,
-                                     gboolean          is_meta,
-                                     GVariant        **out_entry,
-                                     GCancellable     *cancellable,
-                                     GError          **error);
-
-gboolean ostree_parse_file_pack_entry (GVariant       *pack_entry,
-                                       GInputStream  **out_input,
-                                       GFileInfo     **out_info,
-                                       GVariant      **out_xattrs,
-                                       GCancellable   *cancellable,
-                                       GError        **error);
-
-gboolean ostree_pack_index_search (GVariant            *index,
-                                   GVariant           *csum_bytes,
-                                   OstreeObjectType    objtype,
-                                   guint64            *out_offset);
+gboolean ostree_create_temp_dir (GFile            *dir,
+                                 const char       *prefix,
+                                 const char       *suffix,
+                                 GFile           **out_file,
+                                 GCancellable     *cancellable,
+                                 GError          **error);
 
 /** VALIDATION **/
 
@@ -349,10 +303,4 @@ gboolean ostree_validate_structureof_dirtree (GVariant      *index,
 gboolean ostree_validate_structureof_dirmeta (GVariant      *index,
                                               GError       **error);
 
-gboolean ostree_validate_structureof_pack_index (GVariant      *index,
-                                                 GError       **error);
-
-gboolean ostree_validate_structureof_pack_superindex (GVariant      *superindex,
-                                                      GError       **error);
-
 #endif /* _OSTREE_REPO */
