@@ -22,15 +22,20 @@
 
 #include "config.h"
 
+#define _GNU_SOURCE
+
 #include "otutil.h"
 
 #include <gio/gio.h>
+#include <glib/gstdio.h>
 #include <gio/gunixoutputstream.h>
 
 #include <string.h>
 #include <sys/types.h>
+#include <fcntl.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <errno.h>
 #include <dirent.h>
 
 gboolean
