@@ -109,19 +109,12 @@ ot_util_variant_map (GFile              *src,
                      GError            **error)
 {
   gboolean ret = FALSE;
-  const char *path = NULL;
   ot_lvariant GVariant *ret_variant = NULL;
   GMappedFile *mfile = NULL;
-  int fd;
 
-  path = gs_file_get_path_cached (src);
-  if (!ot_unix_open_noatime (path, &fd, error))
-    goto out;
-  mfile = g_mapped_file_new_from_fd (fd, FALSE, error);
+  mfile = gs_file_map_noatime (src, NULL, error);
   if (!mfile)
     goto out;
-  if (!ot_unix_close (fd, error))
-    goto out;
 
   ret_variant = g_variant_new_from_data (type,
                                          g_mapped_file_get_contents (mfile),
