@@ -30,6 +30,7 @@
 
 typedef struct {
   OstreeRepo  *repo;
+  OtAdminBuiltinOpts *admin_opts;
   GFile *ostree_dir;
   char  *osname;
   GFile *osname_dir;
@@ -37,11 +38,9 @@ typedef struct {
 
 static gboolean opt_no_kernel;
 static gboolean opt_force;
-static gboolean opt_host_kernel;
 
 static GOptionEntry options[] = {
   { "no-kernel", 0, 0, G_OPTION_ARG_NONE, &opt_no_kernel, "Don't update kernel related config (initramfs, bootloader)", NULL },
-  { "host-kernel", 0, 0, G_OPTION_ARG_NONE, &opt_host_kernel, "Use currently booted kernel, not kernel from tree", NULL },
   { "force", 0, 0, G_OPTION_ARG_NONE, &opt_force, "Overwrite any existing deployment", NULL },
   { NULL }
 };
@@ -65,8 +64,10 @@ update_current (OtAdminDeploy      *self,
 {
   gboolean ret = FALSE;
   ot_lobj GFile *current_path = NULL;
+  ot_lobj GFile *current_etc_path = NULL;
   ot_lobj GFile *previous_path = NULL;
   ot_lobj GFile *tmp_current_path = NULL;
+  ot_lobj GFile *tmp_current_etc_path = NULL;
   ot_lobj GFile *tmp_previous_path = NULL;
   ot_lobj GFileInfo *previous_info = NULL;
   ot_lfree char *relative_current = NULL;
@@ -74,6 +75,7 @@ update_current (OtAdminDeploy      *self,
   ot_lfree char *relative_previous = NULL;
 
   current_path = g_file_get_child (self->osname_dir, "current");
+  current_etc_path = g_file_get_child (self->osname_dir, "current-etc");
   previous_path = g_file_get_child (self->osname_dir, "previous");
 
   relative_current = g_file_get_relative_path (self->osname_dir, deploy_target);
@@ -112,9 +114,20 @@ update_current (OtAdminDeploy      *self,
       goto out;
     }
 
+  tmp_current_etc_path = g_file_get_child (self->osname_dir, "tmp-current-etc");
+  (void) gs_file_unlink (tmp_current_etc_path, NULL, NULL);
+  if (symlink (relative_current_etc, gs_file_get_path_cached (tmp_current_etc_path)) < 0)
+    {
+      ot_util_set_error_from_errno (error, errno);
+      goto out;
+    }
+
   if (!gs_file_rename (tmp_current_path, current_path,
                        cancellable, error))
     goto out;
+  if (!gs_file_rename (tmp_current_etc_path, current_etc_path,
+                       cancellable, error))
+    goto out;
 
   if (tmp_previous_path)
     {
@@ -391,6 +404,7 @@ deploy_tree (OtAdminDeploy     *self,
   ot_lfree char *checkout_target_name = NULL;
   ot_lfree char *checkout_target_tmp_name = NULL;
   ot_lfree char *resolved_commit = NULL;
+  gs_free char *resolved_previous_commit = NULL;
   GError *temp_error = NULL;
   gboolean skip_checkout;
 
@@ -410,6 +424,8 @@ deploy_tree (OtAdminDeploy     *self,
 
   if (!ostree_repo_resolve_rev (self->repo, revision, FALSE, &resolved_commit, error))
     goto out;
+  if (!ostree_repo_resolve_rev (self->repo, revision, TRUE, &resolved_previous_commit, error))
+    goto out;
 
   root = (OstreeRepoFile*)ostree_repo_file_new_root (self->repo, resolved_commit);
   if (!ostree_repo_file_ensure_resolved (root, error))
@@ -494,6 +510,7 @@ deploy_tree (OtAdminDeploy     *self,
   if (!skip_checkout)
     {
       ProcessOneCheckoutData checkout_data;
+      ot_lobj GFile *triggers_run_path = NULL;
 
       g_print ("ostadmin: Creating deployment %s\n",
                gs_file_get_path_cached (deploy_target_path));
@@ -513,8 +530,13 @@ deploy_tree (OtAdminDeploy     *self,
       if (checkout_data.caught_error)
         goto out;
 
-      if (!ostree_run_triggers_in_root (deploy_target_path_tmp, cancellable, error))
-        goto out;
+      triggers_run_path = g_file_resolve_relative_path (deploy_target_path_tmp, "usr/share/ostree/triggers-run");
+
+      if (!g_file_query_exists (triggers_run_path, NULL))
+        {
+          if (!ostree_run_triggers_in_root (deploy_target_path_tmp, cancellable, error))
+            goto out;
+        }
 
       deploy_target_default_etc_path = ot_gfile_get_child_strconcat (deploy_target_path_tmp, "etc", NULL);
 
@@ -548,7 +570,10 @@ deploy_tree (OtAdminDeploy     *self,
   if (!ostree_repo_write_ref (self->repo, NULL, current_deployment_ref,
                               resolved_commit, error))
     goto out;
-  if (previous_deployment_revision != NULL)
+  /* Only overwrite previous if it's different from what we're deploying now.
+   */
+  if (resolved_previous_commit != NULL
+      && strcmp (resolved_previous_commit, resolved_commit) != 0)
     {
       if (!ostree_repo_write_ref (self->repo, NULL, previous_deployment_ref,
                                   previous_deployment_revision, error))
@@ -583,13 +608,10 @@ do_update_kernel (OtAdminDeploy     *self,
   args = g_ptr_array_new ();
   ot_ptrarray_add_many (args, "ostree", "admin",
                         "--ostree-dir", gs_file_get_path_cached (self->ostree_dir),
+                        "--boot-dir", gs_file_get_path_cached (self->admin_opts->boot_dir),
                         "update-kernel",
                         self->osname,
                         gs_file_get_path_cached (deploy_path), NULL);
-  if (opt_no_kernel)
-    g_ptr_array_add (args, "--modules-only");
-  if (opt_host_kernel)
-    g_ptr_array_add (args, "--host-kernel");
   g_ptr_array_add (args, NULL);
 
   proc = gs_subprocess_new_simple_argv ((char**)args->pdata,
@@ -607,7 +629,7 @@ do_update_kernel (OtAdminDeploy     *self,
 }
 
 gboolean
-ot_admin_builtin_deploy (int argc, char **argv, GFile *ostree_dir, GError **error)
+ot_admin_builtin_deploy (int argc, char **argv, OtAdminBuiltinOpts *admin_opts, GError **error)
 {
   GOptionContext *context;
   OtAdminDeploy self_data;
@@ -635,7 +657,8 @@ ot_admin_builtin_deploy (int argc, char **argv, GFile *ostree_dir, GError **erro
       goto out;
     }
 
-  self->ostree_dir = g_object_ref (ostree_dir);
+  self->admin_opts = admin_opts;
+  self->ostree_dir = g_object_ref (admin_opts->ostree_dir);
 
   if (!ot_admin_ensure_initialized (self->ostree_dir, cancellable, error))
     goto out;
@@ -656,8 +679,11 @@ ot_admin_builtin_deploy (int argc, char **argv, GFile *ostree_dir, GError **erro
                     cancellable, error))
     goto out;
 
-  if (!do_update_kernel (self, deploy_path, cancellable, error))
-    goto out;
+  if (!opt_no_kernel)
+    {
+      if (!do_update_kernel (self, deploy_path, cancellable, error))
+        goto out;
+    }
 
   ret = TRUE;
  out:
