@@ -39,129 +39,8 @@ static GOptionEntry options[] = {
 
 typedef struct {
   OstreeRepo *repo;
-  guint n_pack_files;
 } OtFsckData;
 
-static gboolean
-fsck_one_pack_file (OtFsckData        *data,
-                    const char        *pack_checksum,
-                    gboolean           is_meta,
-                    GCancellable      *cancellable,
-                    GError           **error)
-{
-  gboolean ret = FALSE;
-  guchar objtype_u8;
-  guint64 offset;
-  guint64 pack_size;
-  ot_lfree char *path = NULL;
-  ot_lobj GFileInfo *pack_info = NULL;
-  ot_lobj GInputStream *input = NULL;
-  ot_lvariant GVariant *index_variant = NULL;
-  ot_lobj GFile *pack_index_path = NULL;
-  ot_lobj GFile *pack_data_path = NULL;
-  ot_lfree guchar *pack_content_csum = NULL;
-  ot_lfree char *tmp_checksum = NULL;
-  GVariantIter *index_content_iter = NULL;
-
-  g_free (path);
-  path = ostree_get_relative_pack_index_path (is_meta, pack_checksum);
-  pack_index_path = g_file_resolve_relative_path (ostree_repo_get_path (data->repo), path);
-
-  if (!ot_util_variant_map (pack_index_path,
-                            OSTREE_PACK_INDEX_VARIANT_FORMAT, FALSE,
-                            &index_variant, error))
-    goto out;
-      
-  if (!ostree_validate_structureof_pack_index (index_variant, error))
-    goto out;
-
-  g_free (path);
-  path = ostree_get_relative_pack_data_path (is_meta, pack_checksum);
-  pack_data_path = g_file_resolve_relative_path (ostree_repo_get_path (data->repo), path);
-      
-  input = (GInputStream*)g_file_read (pack_data_path, cancellable, error);
-  if (!input)
-    goto out;
-
-  pack_info = g_file_input_stream_query_info ((GFileInputStream*)input, OSTREE_GIO_FAST_QUERYINFO,
-                                              cancellable, error);
-  if (!pack_info)
-    goto out;
-  pack_size = g_file_info_get_attribute_uint64 (pack_info, "standard::size");
-     
-  if (!ot_gio_checksum_stream (input, &pack_content_csum, cancellable, error))
-    goto out;
-
-  tmp_checksum = ostree_checksum_from_bytes (pack_content_csum);
-  if (strcmp (tmp_checksum, pack_checksum) != 0)
-    {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-                   "corrupted pack '%s', actual checksum is %s",
-                   pack_checksum, tmp_checksum);
-      goto out;
-    }
-
-  g_variant_get_child (index_variant, 2, "a(yayt)", &index_content_iter);
-
-  while (g_variant_iter_loop (index_content_iter, "(y@ayt)",
-                              &objtype_u8, NULL, &offset))
-    {
-      offset = GUINT64_FROM_BE (offset);
-      if (offset > pack_size)
-        {
-          g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-                       "corrupted pack '%s', offset %" G_GUINT64_FORMAT " larger than file size %" G_GUINT64_FORMAT,
-                       pack_checksum,
-                       offset, pack_size);
-          goto out;
-        }
-    }
-
-  ret = TRUE;
- out:
-  if (index_content_iter)
-    g_variant_iter_free (index_content_iter);
-  return ret;
-}
-
-static gboolean
-fsck_pack_files (OtFsckData  *data,
-                 GCancellable   *cancellable,
-                 GError        **error)
-{
-  gboolean ret = FALSE;
-  guint i;
-  ot_lptrarray GPtrArray *meta_pack_indexes = NULL;
-  ot_lptrarray GPtrArray *data_pack_indexes = NULL;
-  
-  if (!ostree_repo_list_pack_indexes (data->repo, &meta_pack_indexes, &data_pack_indexes,
-                                      cancellable, error))
-    goto out;
-
-  for (i = 0; i < meta_pack_indexes->len; i++)
-    {
-      const char *pack_checksum = meta_pack_indexes->pdata[i];
-
-      if (!fsck_one_pack_file (data, pack_checksum, TRUE, cancellable, error))
-        goto out;
-
-      data->n_pack_files++;
-    }
-  for (i = 0; i < data_pack_indexes->len; i++)
-    {
-      const char *pack_checksum = data_pack_indexes->pdata[i];
-
-      if (!fsck_one_pack_file (data, pack_checksum, FALSE, cancellable, error))
-        goto out;
-
-      data->n_pack_files++;
-    }
-
-  ret = TRUE;
- out:
-  return ret;
-}
-
 static gboolean
 fsck_reachable_objects_from_commits (OtFsckData            *data,
                                      GHashTable            *commits,
@@ -208,13 +87,13 @@ fsck_reachable_objects_from_commits (OtFsckData            *data,
 
       g_clear_object (&input);
       g_clear_object (&file_info);
-      ot_clear_gvariant (&xattrs);
+      g_clear_pointer (&xattrs, (GDestroyNotify) g_variant_unref);
 
       if (objtype == OSTREE_OBJECT_TYPE_COMMIT
           || objtype == OSTREE_OBJECT_TYPE_DIR_TREE 
           || objtype == OSTREE_OBJECT_TYPE_DIR_META)
         {
-          ot_clear_gvariant (&metadata);
+          g_clear_pointer (&metadata, (GDestroyNotify) g_variant_unref);
           if (!ostree_repo_load_variant (data->repo, objtype,
                                          checksum, &metadata, error))
             {
@@ -347,7 +226,7 @@ ostree_builtin_fsck (int argc, char **argv, GFile *repo_path, GError **error)
         g_hash_table_insert (commits, g_variant_ref (serialized_key), serialized_key);
     }
 
-  ot_clear_hashtable (&objects);
+  g_clear_pointer (&objects, (GDestroyNotify) g_hash_table_unref);
 
   g_print ("Verifying content integrity of %u commit objects...\n",
            (guint)g_hash_table_size (commits));
@@ -355,11 +234,6 @@ ostree_builtin_fsck (int argc, char **argv, GFile *repo_path, GError **error)
   if (!fsck_reachable_objects_from_commits (&data, commits, cancellable, error))
     goto out;
 
-  g_print ("Verifying structure of pack files...\n");
-
-  if (!fsck_pack_files (&data, cancellable, error))
-    goto out;
-
   ret = TRUE;
  out:
   if (context)
