@@ -37,10 +37,10 @@ typedef struct {
   OstreeRepo *dest_repo;
   GThreadPool *threadpool;
   GMainLoop *loop;
-  gboolean stdout_is_tty;
   int n_objects_to_check;
   volatile int n_objects_checked;
   volatile int n_objects_copied;
+  GSConsole *console;
 } OtLocalCloneData;
 
 static gboolean
@@ -136,11 +136,16 @@ static gboolean
 idle_print_status (gpointer user_data)
 {
   OtLocalCloneData *data = user_data;
+  gs_free char *str = NULL;
 
-  g_print ("%c8pull: %d/%d scanned, %d objects copied", 0x1B,
-           g_atomic_int_get (&data->n_objects_checked),
-           data->n_objects_to_check,
-           g_atomic_int_get (&data->n_objects_copied));
+  str = g_strdup_printf ("pull: %d/%d scanned, %d objects copied",
+                         g_atomic_int_get (&data->n_objects_checked),
+                         data->n_objects_to_check,
+                         g_atomic_int_get (&data->n_objects_copied));
+  if (data->console)
+    gs_console_begin_status_line (data->console, str, NULL, NULL);
+  else
+    g_print ("%s\n", str);
 
   return TRUE;
 }
@@ -162,6 +167,7 @@ ostree_builtin_pull_local (int argc, char **argv, GFile *repo_path, GError **err
   ot_lobj GFile *src_dir = NULL;
   ot_lobj GFile *dest_dir = NULL;
   ot_lhash GHashTable *refs_to_clone = NULL;
+  ot_lhash GHashTable *commits_to_clone = NULL;
   ot_lhash GHashTable *source_objects = NULL;
   ot_lhash GHashTable *objects_to_copy = NULL;
   OtLocalCloneData datav;
@@ -198,7 +204,6 @@ ostree_builtin_pull_local (int argc, char **argv, GFile *repo_path, GError **err
 
   data->threadpool = ot_thread_pool_new_nproc (import_one_object_thread, data);
   data->loop = g_main_loop_new (NULL, TRUE);
-  data->stdout_is_tty = isatty (1);
 
   src_repo_dir = g_object_ref (ostree_repo_get_path (data->src_repo));
   dest_repo_dir = g_object_ref (ostree_repo_get_path (data->dest_repo));
@@ -211,16 +216,24 @@ ostree_builtin_pull_local (int argc, char **argv, GFile *repo_path, GError **err
   else
     {
       refs_to_clone = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
+      commits_to_clone = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, NULL);
       for (i = 2; i < argc; i++)
         {
           const char *ref = argv[i];
           char *rev;
           
-          if (!ostree_repo_resolve_rev (data->src_repo, ref, FALSE, &rev, error))
-            goto out;
+          if (ostree_validate_checksum_string (ref, NULL))
+            {
+              g_hash_table_insert (commits_to_clone, (char*)ref, (char*) ref);
+            }
+          else
+            {
+              if (!ostree_repo_resolve_rev (data->src_repo, ref, FALSE, &rev, error))
+                goto out;
           
-          /* Transfer ownership of rev */
-          g_hash_table_insert (refs_to_clone, g_strdup (ref), rev);
+              /* Transfer ownership of rev */
+              g_hash_table_insert (refs_to_clone, g_strdup (ref), rev);
+            }
         }
     }
 
@@ -228,13 +241,28 @@ ostree_builtin_pull_local (int argc, char **argv, GFile *repo_path, GError **err
 
   source_objects = ostree_traverse_new_reachable ();
 
-  g_hash_table_iter_init (&hash_iter, refs_to_clone);
-  while (g_hash_table_iter_next (&hash_iter, &key, &value))
+  if (refs_to_clone)
     {
-      const char *checksum = value;
+      g_hash_table_iter_init (&hash_iter, refs_to_clone);
+      while (g_hash_table_iter_next (&hash_iter, &key, &value))
+        {
+          const char *checksum = value;
+          
+          if (!ostree_traverse_commit (data->src_repo, checksum, 0, source_objects, cancellable, error))
+            goto out;
+        }
+    }
 
-      if (!ostree_traverse_commit (data->src_repo, checksum, 0, source_objects, cancellable, error))
-        goto out;
+  if (commits_to_clone)
+    {
+      g_hash_table_iter_init (&hash_iter, commits_to_clone);
+      while (g_hash_table_iter_next (&hash_iter, &key, &value))
+        {
+          const char *checksum = key;
+
+          if (!ostree_traverse_commit (data->src_repo, checksum, 0, source_objects, cancellable, error))
+            goto out;
+        }
     }
 
   if (!ostree_repo_prepare_transaction (data->dest_repo, FALSE, cancellable, error))
@@ -250,19 +278,19 @@ ostree_builtin_pull_local (int argc, char **argv, GFile *repo_path, GError **err
 
   if (data->n_objects_to_check > 0)
     {
-      if (data->stdout_is_tty)
-        {
-          g_print ("%c7", 0x1B);
-          g_timeout_add_seconds (1, idle_print_status, data);
-          idle_print_status (data);
-        }
-      
+      data->console = gs_console_get ();
+
+      if (data->console)
+        gs_console_begin_status_line (data->console, "", NULL, NULL);
+
+      g_timeout_add_seconds (1, idle_print_status, data);
+      idle_print_status (data);
+
       g_main_loop_run (data->loop);
 
       idle_print_status (data);
-      
-      if (data->stdout_is_tty)
-        g_print ("\n");
+      if (data->console)
+        gs_console_end_status_line (data->console, NULL, NULL);
     }
 
   if (!ostree_repo_commit_transaction (data->dest_repo, NULL, error))
